summaryrefslogtreecommitdiffstats
path: root/src/replaygainfilelist.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/replaygainfilelist.h')
-rwxr-xr-xsrc/replaygainfilelist.h71
1 files changed, 36 insertions, 35 deletions
diff --git a/src/replaygainfilelist.h b/src/replaygainfilelist.h
index a147c44..1228aea 100755
--- a/src/replaygainfilelist.h
+++ b/src/replaygainfilelist.h
@@ -5,7 +5,7 @@
#include <klistview.h>
-#include <qdatetime.h>
+#include <tqdatetime.h>
class TagEngine;
@@ -14,7 +14,7 @@ class ReplayGain;
class Config;
class Logger;
-class QSimpleRichText;
+class TQSimpleRichText;
class KProgress;
class KPopupMenu;
@@ -44,38 +44,38 @@ public:
/**
* Constructor
* @param parent The parent list view
*/
- ReplayGainFileListItem( QListView* parent );
+ ReplayGainFileListItem( TQListView* tqparent );
/*
* Constructor
* @param parent The parent list view
* @param after The item, the new item should be placed after
*/
- //ReplayGainFileListItem( QListView* parent, QListViewItem* after );
+ //ReplayGainFileListItem( TQListView* tqparent, TQListViewItem* after );
/**
* Constructor
* @param parent The parent list view item
*/
- ReplayGainFileListItem( ReplayGainFileListItem* parent );
+ ReplayGainFileListItem( ReplayGainFileListItem* tqparent );
/**
* Destructor
*/
virtual ~ReplayGainFileListItem();
- virtual void paintCell( QPainter* p, const QColorGroup& cg, int column, int width, int alignment );
+ virtual void paintCell( TQPainter* p, const TQColorGroup& cg, int column, int width, int tqalignment );
- int compare( QListViewItem* item, int column, bool ascending ) const;
+ int compare( TQListViewItem* item, int column, bool ascending ) const;
void updateReplayGainCells( TagData* );
ReplayGainFileListItem* firstChild() const { return static_cast<ReplayGainFileListItem*>( KListViewItem::firstChild() ); }
ReplayGainFileListItem* nextSibling() const { return static_cast<ReplayGainFileListItem*>( KListViewItem::nextSibling() ); }
//ReplayGainFileListItem* itemBelow() { return static_cast<ReplayGainFileListItem*>( KListViewItem::itemBelow() ); }
- ReplayGainFileListItem* parent() const { return static_cast<ReplayGainFileListItem*>( KListViewItem::parent() ); }
+ ReplayGainFileListItem* tqparent() const { return static_cast<ReplayGainFileListItem*>( KListViewItem::tqparent() ); }
Type type() { return m_type; }
void setType( Type );
@@ -86,11 +86,11 @@ public:
* metaflac: 8, 11.025, 12, 16, 22.05, 24, 32, 44.1, or 48 kHz.
*/
- QString filePathName; // the path and name of the file
- //QString fileName; // just the _name_ of the file
- QString mimeType; // the mime type of the file / the mime type of all files in this album
- QString fileFormat; // just the _format_ of the file / the format of all files in this album (for easier use)
- QString originalFileFormat; // after renaming we need to re-rename the file
+ TQString filePathName; // the path and name of the file
+ //TQString fileName; // just the _name_ of the file
+ TQString mimeType; // the mime type of the file / the mime type of all files in this album
+ TQString fileFormat; // just the _format_ of the file / the format of all files in this album (for easier use)
+ TQString originalFileFormat; // after renaming we need to re-rename the file
bool addingReplayGain; // are we adding replay gain tags at the moment?
bool queued; // is this item queued for adding/removing replay gain?
Mode mode;
@@ -109,13 +109,14 @@ private:
class ReplayGainFileList : public KListView
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor
* @param parent The parent widget
* @param name The name of the file list
*/
- ReplayGainFileList( TagEngine*, Config*, Logger*, QWidget *parent=0, const char *name=0 );
+ ReplayGainFileList( TagEngine*, Config*, Logger*, TQWidget *tqparent=0, const char *name=0 );
/**
* Destructor
@@ -123,12 +124,12 @@ public:
virtual ~ReplayGainFileList();
ReplayGainFileListItem* firstChild() const { return static_cast<ReplayGainFileListItem*>( KListView::firstChild() ); }
- ReplayGainFileListItem* itemAt( const QPoint& point ) const { return static_cast<ReplayGainFileListItem*>( KListView::itemAt(point) ); }
+ ReplayGainFileListItem* itemAt( const TQPoint& point ) const { return static_cast<ReplayGainFileListItem*>( KListView::itemAt(point) ); }
- int columnByName( const QString& name );
+ int columnByName( const TQString& name );
protected:
- virtual bool acceptDrag( QDropEvent *e ) const;
+ virtual bool acceptDrag( TQDropEvent *e ) const;
private slots:
void columnResizeEvent( int, int, int );
@@ -137,18 +138,18 @@ private slots:
void update();
public slots:
- void addFile( const QString& );
- void addDir( const QString&, const QStringList& filter = "", bool recursive = true );
+ void addFile( const TQString& );
+ void addDir( const TQString&, const TQStringList& filter = "", bool recursive = true );
void calcAllReplayGain( bool force );
void removeAllReplayGain();
void cancelProcess();
private:
/** Lists all file in a directory and adds them to the file list, if @p fast is false. The number of listed files is returned */
- int listDir( const QString& directory, QStringList filter, bool recursive = true, bool fast = false, int count = 0 );
+ int listDir( const TQString& directory, TQStringList filter, bool recursive = true, bool fast = false, int count = 0 );
/** A progressbar, that is shown, when a directory is added recursive */
- KProgress* pScanStatus;
+ KProgress* pScantqStatus;
TagEngine* tagEngine;
Config* config;
@@ -158,14 +159,14 @@ private:
ReplayGain* replayGain;
int logID;
- void contentsDragEnterEvent( QDragEnterEvent *e );
- void contentsDragMoveEvent( QDragMoveEvent *e );
- void contentsDropEvent( QDropEvent *e );
+ void contentsDragEnterEvent( TQDragEnterEvent *e );
+ void contentsDragMoveEvent( TQDragMoveEvent *e );
+ void contentsDropEvent( TQDropEvent *e );
- void viewportPaintEvent( QPaintEvent* );
- void viewportResizeEvent( QResizeEvent* );
+ void viewportPaintEvent( TQPaintEvent* );
+ void viewportResizeEvent( TQResizeEvent* );
- QSimpleRichText* bubble;
+ TQSimpleRichText* bubble;
void startProcess();
@@ -178,7 +179,7 @@ private:
ReplayGainFileListItem::Mode mode;
ReplayGainFileListItem* currentItem;
- QTimer* tUpdateProgress;
+ TQTimer* tUpdateProgress;
bool processing; // true, if the progress is active (hide some options in the context menu)
int percent; // the progress of the current file / album
int lastPercent; // cache the last percent in order to record a 'track change'
@@ -201,7 +202,7 @@ private:
KAction* close_albums;
private slots:
- void showContextMenu( QListViewItem*, const QPoint&, int );
+ void showContextMenu( TQListViewItem*, const TQPoint&, int );
/**
* Remove selected items from the file list
@@ -223,7 +224,7 @@ private slots:
*/
void removeSelectedItemsGain();
- void slotDropped( QDropEvent*, QListViewItem*, QListViewItem* ); // NOTE rename?
+ void slotDropped( TQDropEvent*, TQListViewItem*, TQListViewItem* ); // NOTE rename?
void processOutput( KProcess*, char*, int );
void processExit( KProcess* );
@@ -231,7 +232,7 @@ private slots:
signals:
//void calcGain();
//void removeGain();
-// void addFile( const QString& filename );
+// void addFile( const TQString& filename );
void processStarted();
void processStopped();
@@ -44,38 +44,38 @@ public:
/**
* Constructor
- * @param parent The parent list view
+ * @param tqparent The tqparent list view
*/
@@ -44,38 +44,38 @@ public:
/*
* Constructor
- * @param parent The parent list view
+ * @param tqparent The tqparent list view
* @param after The item, the new item should be placed after
*/
@@ -44,38 +44,38 @@ public:
/**
* Constructor
- * @param parent The parent list view item
+ * @param tqparent The tqparent list view item
*/
@@ -109,13 +109,14 @@ private:
/**
* Constructor
- * @param parent The parent widget
+ * @param tqparent The tqparent widget
* @param name The name of the file list
*/